#include "customwin.h"

#include <QQuickView>
#include <QDebug>

CustomWin::CustomWin() : QQuickWindow()
{
	connect(this, &CustomWin::inputCutoutChanged, this, &CustomWin::updateCutoutMask);
	connect(this, &CustomWin::inputCutoutEnabledChanged, this, &CustomWin::updateCutoutMask);
	connect(this, &CustomWin::widthChanged, this, &CustomWin::updateCutoutMask);
	connect(this, &CustomWin::heightChanged, this, &CustomWin::updateCutoutMask);
}

CustomWin::~CustomWin()
{
}

void CustomWin::registerWithQML()
{
	qmlRegisterType<CustomWin>("app", 1, 0, "CustomWin");
}

void CustomWin::setInputCutout(const QRect& rect)
{
	if (_inputCutout != rect)
	{
		_inputCutout = rect;
		emit inputCutoutChanged();
	}
}

void CustomWin::setInputCutoutEnabled(bool enable)
{
	if (_inputCutoutEnabled != enable)
	{
		_inputCutoutEnabled = enable;
		emit inputCutoutEnabledChanged();
	}
}

void CustomWin::updateCutoutMask()
{
	if (_inputCutout.isValid() == false || !_inputCutoutEnabled)
	{
		setMask(QRegion());
		return;
	}

	QRegion total(QRect(QPoint(), size()));

	auto insideSize = total.boundingRect().adjusted(_inputCutout.left(), _inputCutout.top(), -_inputCutout.width()+1, -_inputCutout.height()+1);
	QRegion inside(insideSize);

    setMask(total - inside);
}
